==> 0.0.1.tar.gz: lib/widgets/x_states_layout.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:hgg_base/hgg_base.dart';
import 'package:hgg_base/utils/x_size.dart';

/// 基于model的状态页面显示
class XStatesLayout<T extends XBaseModel> extends XGetView<T> {
  final bool isShowLoading;
  final bool loadingShowPage; //在 loading 下方显示页面
  final Widget? onLoading;
  final Widget? onError;
  final Widget? onEmpty;
  final EdgeInsetsGeometry? padding;

  final Widget child;

  XStatesLayout({
    this.isShowLoading = true,
    this.loadingShowPage = false,
    this.onLoading,
    this.onError,
    this.onEmpty,
    this.padding,
    required this.child,
    String? tag,
  }) : super(tag: tag);

  @override
  Widget build(BuildContext context) {
    return Obx(() {
      return Stack(
        children: <Widget>[
          if(loadingShowPage || model.normal)
            child,
          if (isShowLoading && model.loading)
            onLoading ?? PageStateLoading(padding: padding,),
          if (model.error)
            onError ??
                PageStateError(
                  message: model.errorMessage,
                  onPressed: model.refreshWithLoading,
                  padding: padding,
                ),
          if (model.empty)
            onEmpty ??
                PageStateError(
                  image: Icon(
                    Icons.wb_cloudy_outlined,
                    size: D.w(120),
                    color: Colors.grey[500],
                  ),
                  message: '空空如也',
                  onPressed: model.refreshWithLoading,
                  padding: padding,
                ),
        ],
      );
    });
  }
}

/// 加载错误
class PageStateError extends StatelessWidget {
  final VoidCallback? onPressed;
  final String message;
  final Widget? image;
  final EdgeInsetsGeometry? padding;

  PageStateError({
    this.onPressed,
    this.message = '加载失败',
    this.image,
    this.padding,
  });

  @override
  Widget build(BuildContext context) {
    Widget widget = Column(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        image ??
            Icon(
              Icons.error_outline_outlined,
              size: D.w(120),
              color: Colors.grey[500],
            ),
        G.v(20),
        Text(
          message,
          style: TextStyle(
            color: Colors.grey,
            fontSize: D.sp(28),
          ),
        ),
      ],
    );
    if (padding != null) {
      widget = Padding(
        padding: padding!,
        child: widget,
      );
    }
    return InkWell(
      onTap: onPressed,
      child: Center(
        child: widget,
      ),
    );
  }
}

/// 加载中
class PageStateLoading extends StatelessWidget {
  final EdgeInsetsGeometry? padding;

  PageStateLoading({this.padding});

  @override
  Widget build(BuildContext context) {
    Widget widget = Container(
      width: double.infinity,
      height: double.infinity,
      alignment: Alignment.center,
      color: Colors.black12,
      child: Container(
        width: D.w(180),
        height: D.h(180),
        decoration: BoxDecoration(
          color: Colors.black,
          borderRadius: XRadius.circular(20),
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            CupertinoTheme(
                data: CupertinoThemeData(brightness: Brightness.dark),
                child: CupertinoActivityIndicator()),
            G.v(32),
            Text(
              '加载中',
              style: TextStyle(
                fontSize: D.sp(20),
                color: Colors.white70,
              ),
            ),
          ],
        ),
      ),
    );
    if (padding != null) {
      widget = Padding(
        padding: padding!,
        child: widget,
      );
    }
    return widget;
  }
}

==> 1.0.1.tar.gz: lib/widgets/x_states_layout.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:hgg_base/hgg_base.dart';
import 'package:hgg_base/utils/x_size.dart';

/// 基于model的状态页面显示
class XStatesLayout<T extends XBaseModel> extends XGetView<T> {
  final bool isShowLoading;
  final bool loadingShowPage; //在 loading 下方显示页面
  final Widget? onLoading;
  final Widget? onError;
  final Widget? onEmpty;
  final EdgeInsetsGeometry? padding; //加载或错误页面 padding
  final double? loadOrErrorPageHeight; //加载或错误页面 高度

  final Widget child;

  XStatesLayout({
    this.isShowLoading = true,
    this.loadingShowPage = false,
    this.onLoading,
    this.onError,
    this.onEmpty,
    this.padding,
    this.loadOrErrorPageHeight,
    required this.child,
    String? tag,
  }) : super(tag: tag);

  @override
  Widget build(BuildContext context) {
    if (model is XDataModel || model is XListModel) {
      return Obx(() {
        return Stack(
          children: <Widget>[
            if (loadingShowPage || model.normal) child,
            if (isShowLoading && model.loading)
              onLoading ??
                  PageStateLoading(
                    padding: padding,
                    pageHeight: loadOrErrorPageHeight,
                  ),
            if (model.error)
              onError ??
                  PageStateError(
                    message: model.errorMessage,
                    onPressed: model.refreshWithLoading,
                    padding: padding,
                    pageHeight: loadOrErrorPageHeight,
                  ),
            if (model.empty)
              onEmpty ??
                  PageStateError(
                    image: Icon(
                      Icons.wb_cloudy_outlined,
                      size: D.w(120),
                      color: Colors.grey[500],
                    ),
                    message: '空空如也',
                    onPressed: model.refreshWithLoading,
                    padding: padding,
                    pageHeight: loadOrErrorPageHeight,
                  ),
          ],
        );
      });
    } else {
      return child;
    }
  }
}

/// 加载错误
class PageStateError extends StatelessWidget {
  final VoidCallback? onPressed;
  final String message;
  final Widget? image;
  final EdgeInsetsGeometry? padding;
  final double? pageHeight;

  PageStateError(
      {this.onPressed, this.message = '加载失败', this.image, this.padding, this.pageHeight});

  @override
  Widget build(BuildContext context) {
    Widget widget = Column(
      mainAxisAlignment: MainAxisAlignment.center,
      crossAxisAlignment: CrossAxisAlignment.center,
      children: <Widget>[
        image ??
            Icon(
              Icons.error_outline_outlined,
              size: D.w(120),
              color: Colors.grey[500],
            ),
        G.v(20),
        Text(
          message,
          style: TextStyle(
            color: Colors.grey,
            fontSize: D.sp(28),
          ),
        ),
      ],
    );

    if (pageHeight != null) {
      widget = SizedBox(
        height: D.h(pageHeight),
        child: widget,
      );
    }

    if (padding != null) {
      widget = Padding(
        padding: padding!,
        child: widget,
      );
    }
    return InkWell(
      onTap: onPressed,
      child: Center(
        child: widget,
      ),
    );
  }
}

/// 加载中
class PageStateLoading extends StatelessWidget {
  final EdgeInsetsGeometry? padding;
  final double? pageHeight;

  PageStateLoading({this.padding, this.pageHeight});

  @override
  Widget build(BuildContext context) {
    Widget widget = Container(
      width: double.infinity,
      height: double.infinity,
      alignment: Alignment.center,
      color: Colors.black12,
      child: Container(
        width: D.w(180),
        height: D.h(180),
        decoration: BoxDecoration(
          color: Colors.black,
          borderRadius: XRadius.circular(20),
        ),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.center,
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            CupertinoTheme(
                data: CupertinoThemeData(brightness: Brightness.dark),
                child: CupertinoActivityIndicator()),
            G.v(32),
            Text(
              '加载中',
              style: TextStyle(
                fontSize: D.sp(20),
                color: Colors.white70,
              ),
            ),
          ],
        ),
      ),
    );

    if (pageHeight != null) {
      widget = SizedBox(
        height: D.h(pageHeight),
        child: widget,
      );
    }

    if (padding != null) {
      widget = Padding(
        padding: padding!,
        child: widget,
      );
    }
    return widget;
  }
}
